# setup.py
from setuptools import setup, find_packages

def get_version():
    with open("VERSION.txt") as f:
        return f.read().strip()

setup(
    name='passw',
    version=get_version(),
    packages=find_packages(),
    author='kanchan',
   
    description='A simple random password generator',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)




# random_password_generator.py
import random
import string

def generate_random_password(length):
    while True:
        password = random.choices(string.ascii_lowercase, k=1) + \
                   random.choices(string.ascii_uppercase, k=1) + \
                   random.choices(string.digits, k=1) + \
                   random.choices(string.ascii_letters + string.digits, k=length-3)
        random.shuffle(password)
        password = ''.join(password)

        if (any(c.islower() for c in password) and
            any(c.isupper() for c in password) and
            any(c.isdigit() for c in password)):
            break

    return password


def gen_pass():
    pass_len = random.randint(6,11)
    passw = generate_random_password(pass_len)
    return passw
   
